<?php
/*
Plugin Name: PluginTinySlider
Plugin URI: http://www.dimgoto.com/open-source/wordpress/plugins/plugin-tinyslider
Description: Simple Images Slider, <a href="http://www.leigeber.com/" target="_blank">TinySlider (Michael Leigeber, Web Designer)</a> implementation.
Version: 1.0.0
Author: Dimitri GOY
Author URI: http://www.dimgoto.com
*/

/*  Copyright 2009  DimGoTo  (email : wordpress@dimgoto.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/**
 * Classe PluginTinySlider.
 *
 * This Plugin is based on TinySlider powered by Michael Leigeber, implementation to WordPress.
 *
 * @package Plugins
 * @subpackage TinySlider
 * @version 1.0.0
 * @author Dimitri GOY
 * @copyright 2009 - DimGoTo
 * @link http://www.dimgoto.com/
 * @link http://www.leigeber.com/
 */
class PluginTinySlider {

	protected $_pluginname = null;
	protected $_plugindir = null;
	protected $_langdir = null;
	protected $_jsdir = null;
	protected $_cssdir = null;
	protected $_pluginfile = null;
	protected $_galleriesdir = null;
	protected $_imgdir = null;
	protected $_docdir = null;

	function __construct() {

		add_action('init', array($this, 'init'));
	}

	public function init() {

		$this->_pluginname = get_class($this);
		$this->_pluginfile = plugin_basename(__FILE__);
		$this->_plugindir = '/' . PLUGINDIR . '/' . str_replace('\\', '/', dirname(plugin_basename(__FILE__)));
		$this->_langdir = $this->_plugindir . '/lang';
		$this->_jsdir = $GLOBALS['wpbase'] . $this->_plugindir . '/js';
		$this->_cssdir = get_bloginfo('wpurl') . $GLOBALS['wpbase'] . $this->_plugindir . '/css';
		$this->_galleriesdir = '.' . $GLOBALS['wpbase'] . $this->_plugindir . '/galleries';
		$this->_imgdir = '.' . $GLOBALS['wpbase'] . $this->_plugindir . '/img';
		$this->_docdir = '..' . $this->_plugindir . '/doc';

		load_plugin_textdomain($this->_pluginname, null, $this->_langdir);

		if (is_admin()) {

			register_activation_hook($this->_pluginfile, array($this, 'activate'));
			register_deactivation_hook($this->_pluginfile, array($this, 'deactivate'));

			if (function_exists('register_uninstall_hook')) {
	    		register_uninstall_hook($this->_pluginfile, array($this, 'uninstall'));
			}

			add_action('wp_ajax_tinyslider_add', array($this, 'ajax_add'));
			add_action('wp_ajax_tinyslider_update', array($this, 'ajax_update'));
			add_action('wp_ajax_tinyslider_delete', array($this, 'ajax_delete'));
			add_action('wp_ajax_tinyslider_list', array($this, 'ajax_list'));

			if (isset($_GET)
			&& isset($_GET['page'])
			&& $_GET['page'] == $this->_pluginname) {

				wp_enqueue_script('jquery-ui-core');
				wp_enqueue_script('jquery-ui-resizable');
				wp_enqueue_script('jquery-ui-dialog');

				wp_enqueue_script(strtolower($this->_pluginname) . '-jquery-json', $this->_jsdir . '/jquery.json-2.2.js', array(), false);
				wp_enqueue_script(strtolower($this->_pluginname) . '-admin', $this->_jsdir . '/plugintinyslider.js', array(), false);

				wp_enqueue_style(strtolower($this->_pluginname) . '-jquery-ui', $this->_cssdir . '/jquery-ui-1.0.0.css', array(), false, 'screen');
				wp_enqueue_style(strtolower($this->_pluginname) . '-style', $this->_cssdir . '/style.css', array(), false, 'screen');

				add_action('admin_head', array($this, 'head'));
				add_filter('contextual_help', array($this, 'help'));
			}

			add_action('admin_menu', array($this, 'menu'));

		} else {
			wp_enqueue_script('jquery');
			wp_enqueue_script(strtolower($this->_pluginname) . '-tinyslider', $this->_jsdir . '/tinyslider.js', array(), false);
			wp_enqueue_style(strtolower($this->_pluginname) . '-tinyslider', $this->_cssdir . '/tinyslider.css', array(), false, 'screen');

			add_action('wp_head', array($this, 'head'));

			add_shortcode(strtolower($this->_pluginname), array($this, 'shortcode'));
		}

	}

	public function head() {

		$html = '<script type="text/javascript">';

		if (is_admin()
		&& isset($_GET)
		&& isset($_GET['page'])
		&& $_GET['page'] == $this->_pluginname) {
			$html .= 'var vertical_true = "' . __('Oui', $this->_pluginname) . '";';
			$html .= 'var vertical_false = "' . __('Non', $this->_pluginname) . '";';
			$html .= 'var pagination_index = "' . __('Indexe', $this->_pluginname) . '";';
			$html .= 'var pagination_name = "' . __('Nom', $this->_pluginname) . '";';
			$html .= 'var label_ok = "' . __('Ok', $this->_pluginname) . '";';
			$html .= 'var label_cancel = "' . __('Annuler', $this->_pluginname) . '";';
			$html .= 'var label_add = "' . __('Ajouter', $this->_pluginname) . '";';
			$html .= 'var label_update = "' . __('Modifier', $this->_pluginname) . '";';
			$html .= 'var label_delete = "' . __('Supprimer', $this->_pluginname) . '";';
			$html .= 'var label_save = "' . __('Enregistrer', $this->_pluginname) . '";';
			$html .= 'var message_no_tinyslider = "' . __('Aucun TinySlider!', $this->_pluginname) . '";';
			$html .= 'var message_select_least = "' . __('Sélectionnez au moins un élément!', $this->_pluginname) . '";';
			$html .= 'var message_select_single = "' . __('Sélectionnez un seul élément!', $this->_pluginname) . '";';
			$html .= 'var message_gallery_required = "' . __('Sélectionnez une galerie!', $this->_pluginname) . '";';
		} else if ($page_ID) {



		}
		$html .= '</script>';

		echo $html;
	}

	public function menu() {

		add_submenu_page('plugins.php',
				__('TinySlider', $this->__pluginname),
				__('TinySlider', $this->__pluginname),
				'activate_plugins',
				$this->_pluginname,
				array($this, 'control'));
	}

	public function activate() {

		$tinysliders = get_option(strtolower($this->_pluginname));
		if (empty($tinysliders)) {
			add_option(strtolower($this->_pluginname), '');
		}
	}

	public function deactivate() {

	}

	public function uninstall() {

		delete_option(strtolower($this->_pluginname));
	}

	public function help($context = '') {

		$help = '';
		if (file_exists($this->_docdir . '/' . $this->_pluginname . '-' . WPLANG . '.html')) {
			$help .= file_get_contents($this->_docdir . '/' . $this->_pluginname . '-' . WPLANG . '.html');
		} else if (file_exists($this->_docdir . '/' . $this->_pluginname . '-fr_FR.html')) {
			$help .= file_get_contents($this->_docdir . '/' . $this->_pluginname . '-fr_FR.html');
		}
		$help .= $context;

		return $help;
	}

	public function control() {

		$html = '';

		$galleries = array();
		$dir = realpath('.' . $this->_galleriesdir);
		if (is_dir($dir)) {
    		if ($dh = opendir($dir)) {
        		while (($file = readdir($dh)) !== false) {
        			if (is_dir($dir . '/' . $file . '/')
        			&& $file != '.'
        			&& $file != '..') {
        				array_push($galleries, $file);
        			}
        		}
        		closedir($dh);
    		}
		}
		sort($galleries);

		// begin wrap > title
		$html .= '<div class="wrap" id="' . strtolower($this->_pluginname) . '">';
		$html .= '<div id="icon-options-general" class="icon32"><br /></div>';
		$html .= '<h2>' . __('Configuration TinySlider', $this->pluginname) . '</h2>';
		$html .= '<br/>';

		// list tinyslider
		$html .= '<table class="widefat fixed" cellspacing="0" id="' . strtolower($this->_pluginname) . '-tinysliders">';
		$html .= '<thead>';
		$html .= '<tr class="thead">';
		$html .= '<th id="hcb" class="manage-column column-cb check-column" style="" scope="col">';
		$html .= '<input type="checkbox" name="tinyslider-checkbox[]" id="' . strtolower($this->_pluginname) . '-cb0"/>';
		$html .= '</th>';
		$html .= '<th id="htitle" class="manage-column" style="" scope="col">' . __('Titre', $this->_pluginname) . '</th>';
		$html .= '<th id="htemporisation" class="manage-column" style="" scope="col">' . __('Temp.', $this->_pluginname) . '</th>';
		$html .= '<th id="hgallery" class="manage-column" style="" scope="col">' . __('Galerie', $this->_pluginname) . '</th>';
		$html .= '<th id="hpagination" class="manage-column" style="" scope="col">' . __('Pagination', $this->_pluginname) . '</th>';
		$html .= '<th id="hvertical" class="manage-column" style="" scope="col">' . __('Vertical', $this->_pluginname) . '</th>';
		$html .= '<th id="hshortcode" class="manage-column" style="" scope="col">' . __('ShortCode', $this->_pluginname) . '</th>';
		$html .= '</tr>';
		$html .= '</thead>';
		$html .= '<tfoot>';
		$html .= '<tr class="thead">';
		$html .= '<th id="fcb" class="manage-column column-cb check-column" style="" scope="col">';
		$html .= '<input type="checkbox" name="tinyslider-checkbox[]" id="' . strtolower($this->_pluginname) . '-cb1"/>';
		$html .= '</th>';
		$html .= '<th id="ftitle" class="manage-column" style="" scope="col">' . __('Titre', $this->_pluginname) . '</th>';
		$html .= '<th id="ftemporisation" class="manage-column" style="" scope="col">' . __('Temp.', $this->_pluginname) . '</th>';
		$html .= '<th id="fgallery" class="manage-column" style="" scope="col">' . __('Galerie', $this->_pluginname) . '</th>';
		$html .= '<th id="fpagination" class="manage-column" style="" scope="col">' . __('Pagination', $this->_pluginname) . '</th>';
		$html .= '<th id="fvertical" class="manage-column" style="" scope="col">' . __('Vertical', $this->_pluginname) . '</th>';
		$html .= '<th id="fshortcode" class="manage-column" style="" scope="col">' . __('ShortCode', $this->_pluginname) . '</th>';
		$html .= '</tr>';
		$html .= '</foot>';
		$html .= '<tbody id="' . strtolower($this->_pluginname) . '-list">';
		$html .= '</tbody>';
		$html .= '</table>';
		$html .= '<p class="description">' . __('Pour modifier l\'apparence du TinySlider veuillez utiliser l\'éditeur d\'Extensions et modifier le style (tinyslider.css, uniquement!)', $this->_pluginname) . '</p>';

		// buttons
		$html .= '<p class="submit">';
		$html .= '<input class="button-secondary" type="button" value="' . __('Ajouter', $this->_pluginname) . '" id="' . strtolower($this->_pluginname) . '-add" name="' . strtolower($this->_pluginname) . '-add"/>';
		$html .= '<input class="button-secondary" type="button" value="' . __('Supprimer', $this->_pluginname) . '" id="' . strtolower($this->_pluginname) . '-delete" name="' . strtolower($this->_pluginname) . '-delete"/>';
		$html .= '<input class="button-secondary" type="button" value="' . __('Modifier', $this->_pluginname) . '" id="' . strtolower($this->_pluginname) . '-update" name="' . strtolower($this->_pluginname) . '-update"/>';
		$html .= '</p>';

		$html .= '</div>'; // end wrap

		// dialog notification:
		$html .= '<div id="' . strtolower($this->_pluginname) . '-dialog-notification" title="' . __('Notification', $this->_pluginname) . '">';
		$html .= '<div class="ui-state-highlight ui-corner-all">';
		$html .= '<p class="ui-icon ui-icon-info" style="float: left; margin: 1em;"/>';
		$html .= '<p id="' . strtolower($this->_pluginname) . '-notification-message"/>';
		$html .= '</div>';
		$html .= '</div>';

		// dialog error:
		$html .= '<div id="' . strtolower($this->_pluginname) . '-dialog-error" title="' . __('Erreur', $this->_pluginname) . '">';
		$html .= '<div  class="ui-state-error ui-corner-all">';
		$html .= '<p class="ui-icon ui-icon-alert" style="float: left; margin: 1em;"/>';
		$html .= '<p id="' . strtolower($this->_pluginname) . '-error-message"/>';
		$html .= '</div>';
		$html .= '</div>';

		// dialog add tinyslider:
		$html .= '<div id="' . strtolower($this->_pluginname) . '-dialog-add" title="' . __('Ajouter TinySlider', $this->_pluginname) . '">';
		$html .= '<p class="description"><span class="required">*</span> : ' . __('Champ obligatoire', $this->_pluginname) . '</p>';
		$html .= '<form>';
		$html .= '<table class="form-table">';
		$html .= '<tr>';
		$html .= '<th scope="row"><label for="' . strtolower($this->_pluginname) . '-add-title">' . __('Titre', $this->_pluginname) . '</label></th>';
		$html .= '<td><input type="text" id="' . strtolower($this->_pluginname) . '-add-title" name="' . strtolower($this->_pluginname) . '-add-title"/></td>';
		$html .= '</tr>';
		$html .= '<tr>';
		$html .= '<th scope="row"><label for="' . strtolower($this->_pluginname) . '-add-temporisation">' . __('Temporisation', $this->_pluginname) . '</label><span class="required">*</span>';
		$html .= '<br/><span class="description">' . __('(0-désactivé, 1-rapide, ... 10-lent)', $this->_pluginname) . '</span></th>';
		$html .= '<td><input type="text" id="' . strtolower($this->_pluginname) . '-add-temporisation" name="' . strtolower($this->_pluginname) . '-add-temporisation" value="0"/></td>';
		$html .= '</tr>';
		$html .= '<tr>';
		$html .= '<th scope="row"><label for="' . strtolower($this->_pluginname) . '-add-gallery">' . __('Galerie images', $this->_pluginname) . '</label><span class="required">*</span></th>';
		$html .= '<td><select type="text" id="' . strtolower($this->_pluginname) . '-add-gallery" name="' . strtolower($this->_pluginname) . '-add-gallery">';
		$html .= '<option value="">' . __('sélectionner...', $this->_pluginname) . '</option>';
		foreach ($galleries as $gallery) {
			$html .= '<option value="' . $gallery . '">' . $gallery . '</option>';
		}
		$html .= '</select>';
		$html .= '</td>';
		$html .= '</tr>';
		$html .= '<tr>';
		$html .= '<th scope="row"><label for="' . strtolower($this->_pluginname) . '-add-pagination">' . __('Pagination', $this->_pluginname) . '</label></th>';
		$html .= '<td><select id="' . strtolower($this->_pluginname) . '-add-pagination" name="' . strtolower($this->_pluginname) . '-add-pagination" >';
		$html .= '<option value="index" selected="selected">' . __('Indexe', $this->_pluginname) . '</option>';
		$html .= '<option value="name">' . __('Nom image', $this->_pluginname) . '</option>';
		$html .= '</select>';
		$html .= '</td>';
		$html .= '</tr>';
		$html .= '<tr>';
		$html .= '<th scope="row"><label for="' . strtolower($this->_pluginname) . '-add-vertical">' . __('Vertical', $this->_pluginname) . '</label></th>';
		$html .= '<td><select id="' . strtolower($this->_pluginname) . '-add-vertical" name="' . strtolower($this->_pluginname) . '-add-vertical" >';
		$html .= '<option value="true" selected="selected">' . __('Oui', $this->_pluginname) . '</option>';
		$html .= '<option value="false">' . __('Non', $this->_pluginname) . '</option>';
		$html .= '</select>';
		$html .= '</td>';
		$html .= '</tr>';
		$html .= '</table>';
		$html .= '</form>';
		$html .= '<div id="' . strtolower($this->_pluginname) . '-add-error" class="ui-state-error ui-corner-all" style="margin: 2em; display: none;">';
		$html .= '<p class="ui-icon ui-icon-alert" style="float: left; margin: 1em;"/>';
		$html .= '<p id="' . strtolower($this->_pluginname) . '-add-error-message"/>';
		$html .= '</div>';
		$html .= '</div>';

		// dialog update tinyslider:
		$html .= '<div id="' . strtolower($this->_pluginname) . '-dialog-update" title="' . __('Modifier TinySlider', $this->_pluginname) . '">';
		$html .= '<p class="description"><span class="required">*</span> : ' . __('Champ obligatoire', $this->_pluginname) . '</p>';
		$html .= '<form>';
		$html .= '<table class="form-table">';
		$html .= '<tr>';
		$html .= '<th scope="row"><label for="' . strtolower($this->_pluginname) . '-update-title">' . __('Titre', $this->_pluginname) . '</label></th>';
		$html .= '<td><input type="text" id="' . strtolower($this->_pluginname) . '-update-title" name="' . strtolower($this->_pluginname) . '-update-title"/></td>';
		$html .= '</tr>';
		$html .= '<tr>';
		$html .= '<th scope="row"><label for="' . strtolower($this->_pluginname) . '-update-temporisation">' . __('Temporisation', $this->_pluginname) . '</label><span class="required">*</span>';
		$html .= '<br/><span class="description">' . __('(0-désactivé, 1-rapide, ... 10-lent)', $this->_pluginname) . '</span></th>';
		$html .= '<td><input type="text" id="' . strtolower($this->_pluginname) . '-update-temporisation" name="' . strtolower($this->_pluginname) . '-update-temporisation" value="0"/></td>';
		$html .= '</tr>';
		$html .= '<tr>';
		$html .= '<th scope="row"><label for="' . strtolower($this->_pluginname) . '-update-gallery">' . __('Galerie images', $this->_pluginname) . '</label><span class="required">*</span></th>';
		$html .= '<td><select type="text" id="' . strtolower($this->_pluginname) . '-update-gallery" name="' . strtolower($this->_pluginname) . '-update-gallery">';
		$html .= '<option value="">' . __('sélectionner...', $this->_pluginname) . '</option>';
		foreach ($galleries as $gallery) {
			$html .= '<option value="' . $gallery . '">' . $gallery . '</option>';
		}
		$html .= '</select>';
		$html .= '</td>';
		$html .= '</tr>';
		$html .= '<tr>';
		$html .= '<th scope="row"><label for="' . strtolower($this->_pluginname) . '-update-pagination">' . __('Pagination', $this->_pluginname) . '</label></th>';
		$html .= '<td><select id="' . strtolower($this->_pluginname) . '-update-pagination" name="' . strtolower($this->_pluginname) . '-update-pagination" >';
		$html .= '<option value="index" selected="selected">' . __('Indexe', $this->_pluginname) . '</option>';
		$html .= '<option value="name">' . __('Nom image', $this->_pluginname) . '</option>';
		$html .= '</select>';
		$html .= '</td>';
		$html .= '</tr>';
		$html .= '<tr>';
		$html .= '<th scope="row"><label for="' . strtolower($this->_pluginname) . '-update-vertical">' . __('Vertical', $this->_pluginname) . '</label></th>';
		$html .= '<td><select id="' . strtolower($this->_pluginname) . '-update-vertical" name="' . strtolower($this->_pluginname) . '-update-vertical" >';
		$html .= '<option value="true" selected="selected">' . __('Oui', $this->_pluginname) . '</option>';
		$html .= '<option value="false">' . __('Non', $this->_pluginname) . '</option>';
		$html .= '</select>';
		$html .= '</td>';
		$html .= '</tr>';
		$html .= '</table>';
		$html .= '</form>';
		$html .= '<div id="' . strtolower($this->_pluginname) . '-update-error" class="ui-state-error ui-corner-all" style="margin: 2em; display: none;">';
		$html .= '<p class="ui-icon ui-icon-alert" style="float: left; margin: 1em;"/>';
		$html .= '<p id="' . strtolower($this->_pluginname) . '-update-error-message"/>';
		$html .= '</div>';
		$html .= '</div>';

		echo $html;
	}

	public function shortcode($attributes, $content = '') {
		extract(shortcode_atts(array(
												'id' => ''
											),
											$attributes));

		if (isset($id)) {
			$thetiny = null;
			$tinysliders = get_option(strtolower($this->_pluginname));
			foreach ($tinysliders as $tinyslider) {
				if ($tinyslider['id'] == $id) {
					$thetiny = $tinyslider;
					break;
				}
			}

			if (!is_null($thetiny)) {
				$html = '';

				// title
				if (!empty($thetiny['title'])) {
					$html .= '<div id="title">';
					$html .= '<h1>' . $thetiny['title'] . '</h1>';
					$html .= '</div>';
				}

				$html .= '<div id="wrapper">';
				$html .= '<div>';
				// previous
				$html .= '<div id="sliderleft" class="sliderbutton">';
				$html .= '<img src="' . get_bloginfo('wpurl') . '/' . $this->_imgdir . '/left.gif" title="' . __('Précédent', $this->_pluginname) . '" alt="' . __('Précédent', $this->_pluginname) . '" onclick="slideshow.move(-1)" />';
				$html .= '</div>';
				$html .= '<div id="slider">';
				$html .= '<ul>';
				// images
				$dir = $this->_galleriesdir . '/' . $thetiny['gallery'];
				$paginations = array();
				if (is_dir($dir)) {
    				if ($dh = opendir($dir)) {
        				while (($file = readdir($dh)) !== false) {
        					if (!is_dir($dir . $file)
        					&& $file != '.'
        					&& $file != '..') {
            					$pi = pathinfo($file);
        						array_push($paginations, $pi['filename']);
            					$html .= '<li><img src="' . get_bloginfo('wpurl') . '/' . substr($dir, 2) . '/' . $file . '" alt="' . $pi['filename'] . '" title="' . $pi['filename'] . '" /></li>';
        					}
        				}
        			closedir($dh);
    				}
				}
				$html .= '</ul>';
				$html .= '</div>';
				// next
				$html .= '<div id="sliderright" class="sliderbutton">';
				$html .= '<img src="' . get_bloginfo('wpurl') . '/' . $this->_imgdir . '/right.gif" title="' . __('Suivant', $this->_pluginname) . '" alt="' . __('Suivant', $this->_pluginname) . '" onclick="slideshow.move(1)" />';
				$html .= '</div>';
				$html .= '</div>';

				// pagination
				$html .= '<ul id="pagination" class="pagination">';
				foreach ($paginations as $k => $pagination) {
					if ($thetiny['pagination'] == 'index') {
						$label = (int) $k + 1;
					} else {
						$label = $pagination;
					}
					$html .= '<li onclick="slideshow.pos(' . $k . ')">' . $label . '</li>';
				}
				$html .= '</ul>';
				$html .= '</div>';
				// script
				$html .= '<script type="text/javascript">';
				$html .= 'var slideshow=new TINY.slider.slide("slideshow", {';
				$html .=	'id:\'slider\',';
				$html .= 'auto:' . $thetiny['temporisation'] .',';
				$html .= 'resume:true,';
				$html .= 'vertical:' . $thetiny['vertical'] . ',';
				$html .= 'navid:\'pagination\',';
				$html .= 'activeclass:\'current\',';
				$html .= 'position:0';
				$html .= '});';
				$html .= '</script>';

				$content .= $html;
			}
		}

		return $content;
	}

	public function ajax_add() {
		if (!isset($_POST)) {
			header("Status: 400 Bad Request", true, 400);
			die(__('Paramètres TinySlider manquants!', $this->_pluginname));
		} else if (!isset($_POST['tinyslider_title'])) {
			header("Status: 400 Bad Request", true, 400);
			die(__('Paramètre Titre manquant!', $this->_pluginname));
		} else if (!isset($_POST['tinyslider_temporisation'])) {
			header("Status: 400 Bad Request", true, 400);
			die(__('Paramètre Temporisation manquant!', $this->_pluginname));
		} else if (!isset($_POST['tinyslider_gallery'])
		|| empty($_POST['tinyslider_gallery'])) {
			header("Status: 400 Bad Request", true, 400);
			die(__('Paramètre Galerie manquant!', $this->_pluginname));
		} else if (!isset($_POST['tinyslider_pagination'])
		|| empty($_POST['tinyslider_pagination'])) {
			header("Status: 400 Bad Request", true, 400);
			die(__('Paramètre Pagination manquant!', $this->_pluginname));
		} else if (!isset($_POST['tinyslider_vertical'])
		|| empty($_POST['tinyslider_vertical'])) {
			header("Status: 400 Bad Request", true, 400);
			die(__('Paramètre Pagination manquant!', $this->_pluginname));
		} else {
			$tinysliders = get_option(strtolower($this->_pluginname));
			if (empty($tinysliders)) {
				$tinysliders = array();
			}
			$tinyslider = array(
									'id'					=> time(),
									'title'				=> $_POST['tinyslider_title'],
									'temporisation'	=> $_POST['tinyslider_temporisation'],
									'gallery'			=> $_POST['tinyslider_gallery'],
									'pagination'		=> $_POST['tinyslider_pagination'],
									'vertical'			=> $_POST['tinyslider_vertical']
							);
			if (!in_array($tinyslider['gallery'], $tinysliders)) {
				array_push($tinysliders, $tinyslider);
				update_option(strtolower($this->_pluginname), $tinysliders);
				echo sprintf(__('TinySlider ID: %s ajouté!', $this->_pluginname), $tinyslider['id']);
			} else {
				header("Status: 400 Bad Request", true, 400);
				die(__('TinySlider existe déjà pour cette galerie!', $this->_pluginname));
			}
		}
	}

	public function ajax_update() {
	if (!isset($_POST)) {
			header("Status: 400 Bad Request", true, 400);
			die(__('Paramètres TinySlider manquants!', $this->_pluginname));
		} else if (!isset($_POST['tinyslider_id'])
		|| empty($_POST['tinyslider_id'])) {
			header("Status: 400 Bad Request", true, 400);
			die(__('Paramètre ID manquant!', $this->_pluginname));
		} else if (!isset($_POST['tinyslider_title'])) {
			header("Status: 400 Bad Request", true, 400);
			die(__('Paramètre Titre manquant!', $this->_pluginname));
		} else if (!isset($_POST['tinyslider_temporisation'])) {
			header("Status: 400 Bad Request", true, 400);
			die(__('Paramètre Temporisation manquant!', $this->_pluginname));
		} else if (!isset($_POST['tinyslider_gallery'])
		|| empty($_POST['tinyslider_gallery'])) {
			header("Status: 400 Bad Request", true, 400);
			die(__('Paramètre Galerie manquant!', $this->_pluginname));
		} else if (!isset($_POST['tinyslider_pagination'])
		|| empty($_POST['tinyslider_pagination'])) {
			header("Status: 400 Bad Request", true, 400);
			die(__('Paramètre Pagination manquant!', $this->_pluginname));
		} else if (!isset($_POST['tinyslider_vertical'])
		|| empty($_POST['tinyslider_vertical'])) {
			header("Status: 400 Bad Request", true, 400);
			die(__('Paramètre Pagination manquant!', $this->_pluginname));
		} else {
			$tinysliders = get_option(strtolower($this->_pluginname));
			if (!empty($tinysliders)) {
				$thetiny = array(
									'id'					=> $_POST['tinyslider_id'],
									'title'				=> $_POST['tinyslider_title'],
									'temporisation'	=> $_POST['tinyslider_temporisation'],
									'gallery'			=> $_POST['tinyslider_gallery'],
									'pagination'		=> $_POST['tinyslider_pagination'],
									'vertical'			=> $_POST['tinyslider_vertical']
							);
				$replacetinysliders = array();
				$exists = false;
				foreach ($tinysliders as $tinyslider) {
					if ($thetiny['id'] != $tinyslider['id']) {
						array_push($replacetinysliders, $tinyslider);
					} else {
						array_push($replacetinysliders, $thetiny);
						$exists = true;
					}
				}
				if ($exists == true) {
					$tinysliders = $replacetinysliders;
					update_option(strtolower($this->_pluginname), $tinysliders);
					echo sprintf(__('TinySlider ID: %s modifié!', $this->_pluginname), $thetiny['id']);
				} else {
					header("Status: 400 Bad Request", true, 400);
					die(sprintf(__('TinySlider ID: %s n\'existe pas!', $this->_pluginname), $thetiny['id']));
				}
			} else {
				header("Status: 400 Bad Request", true, 400);
				die(__('Aucun TinySlider configuré! Veuillez l\'ajouter', $this->_pluginname));
			}
		}
	}

	public function ajax_delete() {

		if (isset($_POST)
		&& isset($_POST['tinyslider_ids'])) {
			$tinyslider_ids = json_decode($_POST['tinyslider_id']);
			$tinysliders = get_option(strtolower($this->_pluginname));
			if (!empty($tinysliders)) {
				$tmptinysliders = array();
				foreach ($tinyslider_ids as $tinyslider_id) {
					foreach ($tinysliders as $tinyslider) {
						if ($tinyslider['id'] != $tinyslider_id) {
							array_push($tmptinysliders, $tinyslider);
						}
					}
				}
				update_option(strtolower($this->_pluginname), $tmptinysliders);
				echo sprintf(__('TinySlider ID(s): %s supprimé(s)!', $this->_pluginname), implode(', ', $tinyslider_ids));
			} else {
				header("Status: 400 Bad Request", true, 400);
				die(__('ID TinySlider n\'existe pas!', $this->_pluginname));
			}
		} else {
			header("Status: 400 Bad Request", true, 400);
			die(__('ID TinySlider manquant ou vide!', $this->_pluginname));
		}
	}

	public function ajax_list() {

		$tinysliders = get_option(strtolower($this->_pluginname));
		if (!empty($tinysliders)) {
			usort($tinysliders, array($this, 'sort'));
			$data = json_encode($tinysliders);
		} else {
			$data = '';
		}
		echo $data;
	}

	private function sort($arr1, $arr2) {
		$ret = strnatcmp($arr1['title'], $arr2['title']);
		if (!$ret) {
			$ret = strnatcmp($arr1['gallery'], $arr2['gallery']);
		}
		return $ret;
	}
}
new PluginTinySlider();
?>